@@ -1,13 +1,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/components/controls/amd/pm/advanced/pmadvanced.h"
 
-namespace Tests {
-namespace AMD {
-namespace PMAdvanced {
+namespace Tests::AMD::PMAdvanced {
 
 TEST_CASE("AMD PMAdvanced tests", "[GPU][AMD][PM][PMAdvanced]")
 {
@@ -25,6 +23,5 @@ TEST_CASE("AMD PMAdvanced tests", "[GPU][AMD][PM][PMAdvanced]")
     REQUIRE_FALSE(ts.active());
   }
 }
-} // namespace PMAdvanced
-} // namespace AMD
-} // namespace Tests
+
+} // namespace Tests::AMD::PMAdvanced
